"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RetrySemantic = void 0;
var RetrySemantic;
(function (RetrySemantic) {
    RetrySemantic[RetrySemantic["NotRetryable"] = 0] = "NotRetryable";
    RetrySemantic[RetrySemantic["Retryable"] = 1] = "Retryable";
})(RetrySemantic = exports.RetrySemantic || (exports.RetrySemantic = {}));
