/// <reference types="node" />
/**
 * Generated by the protoc-gen-ts.  DO NOT EDIT!
 * compiler version: 3.19.1
 * source: webhook.proto
 * git: https://github.com/thesayyn/protoc-gen-ts */
import * as pb_1 from "google-protobuf";
import * as grpc_1 from "@grpc/grpc-js";
export declare namespace webhook {
    export class _WebhookId extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            cache_name?: string;
            webhook_name?: string;
        });
        get cache_name(): string;
        set cache_name(value: string);
        get webhook_name(): string;
        set webhook_name(value: string);
        static fromObject(data: {
            cache_name?: string;
            webhook_name?: string;
        }): _WebhookId;
        toObject(): {
            cache_name?: string;
            webhook_name?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _WebhookId;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _WebhookId;
    }
    export class _Webhook extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            webhook_id?: _WebhookId;
            topic_name?: string;
            destination?: _WebhookDestination;
        });
        get webhook_id(): _WebhookId;
        set webhook_id(value: _WebhookId);
        get has_webhook_id(): boolean;
        get topic_name(): string;
        set topic_name(value: string);
        get destination(): _WebhookDestination;
        set destination(value: _WebhookDestination);
        get has_destination(): boolean;
        static fromObject(data: {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
            topic_name?: string;
            destination?: ReturnType<typeof _WebhookDestination.prototype.toObject>;
        }): _Webhook;
        toObject(): {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
            topic_name?: string;
            destination?: ReturnType<typeof _WebhookDestination.prototype.toObject>;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _Webhook;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _Webhook;
    }
    export class _PutWebhookRequest extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            webhook?: _Webhook;
        });
        get webhook(): _Webhook;
        set webhook(value: _Webhook);
        get has_webhook(): boolean;
        static fromObject(data: {
            webhook?: ReturnType<typeof _Webhook.prototype.toObject>;
        }): _PutWebhookRequest;
        toObject(): {
            webhook?: ReturnType<typeof _Webhook.prototype.toObject>;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _PutWebhookRequest;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _PutWebhookRequest;
    }
    export class _PutWebhookResponse extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            secret_string?: string;
        });
        get secret_string(): string;
        set secret_string(value: string);
        static fromObject(data: {
            secret_string?: string;
        }): _PutWebhookResponse;
        toObject(): {
            secret_string?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _PutWebhookResponse;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _PutWebhookResponse;
    }
    export class _DeleteWebhookRequest extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            webhook_id?: _WebhookId;
        });
        get webhook_id(): _WebhookId;
        set webhook_id(value: _WebhookId);
        get has_webhook_id(): boolean;
        static fromObject(data: {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
        }): _DeleteWebhookRequest;
        toObject(): {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _DeleteWebhookRequest;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _DeleteWebhookRequest;
    }
    export class _DeleteWebhookResponse extends pb_1.Message {
        #private;
        constructor(data?: any[] | {});
        static fromObject(data: {}): _DeleteWebhookResponse;
        toObject(): {};
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _DeleteWebhookResponse;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _DeleteWebhookResponse;
    }
    export class _ListWebhookRequest extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            cache_name?: string;
        });
        get cache_name(): string;
        set cache_name(value: string);
        static fromObject(data: {
            cache_name?: string;
        }): _ListWebhookRequest;
        toObject(): {
            cache_name?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _ListWebhookRequest;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _ListWebhookRequest;
    }
    export class _ListWebhooksResponse extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            webhook?: _Webhook[];
        });
        get webhook(): _Webhook[];
        set webhook(value: _Webhook[]);
        static fromObject(data: {
            webhook?: ReturnType<typeof _Webhook.prototype.toObject>[];
        }): _ListWebhooksResponse;
        toObject(): {
            webhook?: ReturnType<typeof _Webhook.prototype.toObject>[];
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _ListWebhooksResponse;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _ListWebhooksResponse;
    }
    export class _GetWebhookSecretRequest extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            cache_name?: string;
            webhook_name?: string;
        });
        get cache_name(): string;
        set cache_name(value: string);
        get webhook_name(): string;
        set webhook_name(value: string);
        static fromObject(data: {
            cache_name?: string;
            webhook_name?: string;
        }): _GetWebhookSecretRequest;
        toObject(): {
            cache_name?: string;
            webhook_name?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _GetWebhookSecretRequest;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _GetWebhookSecretRequest;
    }
    export class _GetWebhookSecretResponse extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            cache_name?: string;
            webhook_name?: string;
            secret_string?: string;
        });
        get cache_name(): string;
        set cache_name(value: string);
        get webhook_name(): string;
        set webhook_name(value: string);
        get secret_string(): string;
        set secret_string(value: string);
        static fromObject(data: {
            cache_name?: string;
            webhook_name?: string;
            secret_string?: string;
        }): _GetWebhookSecretResponse;
        toObject(): {
            cache_name?: string;
            webhook_name?: string;
            secret_string?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _GetWebhookSecretResponse;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _GetWebhookSecretResponse;
    }
    export class _WebhookDestination extends pb_1.Message {
        #private;
        constructor(data?: any[] | ({} & (({
            post_url?: string;
        }))));
        get post_url(): string;
        set post_url(value: string);
        get has_post_url(): boolean;
        get kind(): "none" | "post_url";
        static fromObject(data: {
            post_url?: string;
        }): _WebhookDestination;
        toObject(): {
            post_url?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _WebhookDestination;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _WebhookDestination;
    }
    export class _RotateWebhookSecretRequest extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            webhook_id?: _WebhookId;
        });
        get webhook_id(): _WebhookId;
        set webhook_id(value: _WebhookId);
        get has_webhook_id(): boolean;
        static fromObject(data: {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
        }): _RotateWebhookSecretRequest;
        toObject(): {
            webhook_id?: ReturnType<typeof _WebhookId.prototype.toObject>;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _RotateWebhookSecretRequest;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _RotateWebhookSecretRequest;
    }
    export class _RotateWebhookSecretResponse extends pb_1.Message {
        #private;
        constructor(data?: any[] | {
            secret_string?: string;
        });
        get secret_string(): string;
        set secret_string(value: string);
        static fromObject(data: {
            secret_string?: string;
        }): _RotateWebhookSecretResponse;
        toObject(): {
            secret_string?: string;
        };
        serialize(): Uint8Array;
        serialize(w: pb_1.BinaryWriter): void;
        static deserialize(bytes: Uint8Array | pb_1.BinaryReader): _RotateWebhookSecretResponse;
        serializeBinary(): Uint8Array;
        static deserializeBinary(bytes: Uint8Array): _RotateWebhookSecretResponse;
    }
    interface GrpcUnaryServiceInterface<P, R> {
        (message: P, metadata: grpc_1.Metadata, options: grpc_1.CallOptions, callback: grpc_1.requestCallback<R>): grpc_1.ClientUnaryCall;
        (message: P, metadata: grpc_1.Metadata, callback: grpc_1.requestCallback<R>): grpc_1.ClientUnaryCall;
        (message: P, options: grpc_1.CallOptions, callback: grpc_1.requestCallback<R>): grpc_1.ClientUnaryCall;
        (message: P, callback: grpc_1.requestCallback<R>): grpc_1.ClientUnaryCall;
    }
    export abstract class UnimplementedWebhookService {
        static definition: {
            PutWebhook: {
                path: string;
                requestStream: boolean;
                responseStream: boolean;
                requestSerialize: (message: _PutWebhookRequest) => Buffer;
                requestDeserialize: (bytes: Buffer) => _PutWebhookRequest;
                responseSerialize: (message: _PutWebhookResponse) => Buffer;
                responseDeserialize: (bytes: Buffer) => _PutWebhookResponse;
            };
            DeleteWebhook: {
                path: string;
                requestStream: boolean;
                responseStream: boolean;
                requestSerialize: (message: _DeleteWebhookRequest) => Buffer;
                requestDeserialize: (bytes: Buffer) => _DeleteWebhookRequest;
                responseSerialize: (message: _DeleteWebhookResponse) => Buffer;
                responseDeserialize: (bytes: Buffer) => _DeleteWebhookResponse;
            };
            ListWebhooks: {
                path: string;
                requestStream: boolean;
                responseStream: boolean;
                requestSerialize: (message: _ListWebhookRequest) => Buffer;
                requestDeserialize: (bytes: Buffer) => _ListWebhookRequest;
                responseSerialize: (message: _ListWebhooksResponse) => Buffer;
                responseDeserialize: (bytes: Buffer) => _ListWebhooksResponse;
            };
            GetWebhookSecret: {
                path: string;
                requestStream: boolean;
                responseStream: boolean;
                requestSerialize: (message: _GetWebhookSecretRequest) => Buffer;
                requestDeserialize: (bytes: Buffer) => _GetWebhookSecretRequest;
                responseSerialize: (message: _GetWebhookSecretResponse) => Buffer;
                responseDeserialize: (bytes: Buffer) => _GetWebhookSecretResponse;
            };
            RotateWebhookSecret: {
                path: string;
                requestStream: boolean;
                responseStream: boolean;
                requestSerialize: (message: _RotateWebhookSecretRequest) => Buffer;
                requestDeserialize: (bytes: Buffer) => _RotateWebhookSecretRequest;
                responseSerialize: (message: _RotateWebhookSecretResponse) => Buffer;
                responseDeserialize: (bytes: Buffer) => _RotateWebhookSecretResponse;
            };
        };
        [method: string]: grpc_1.UntypedHandleCall;
        abstract PutWebhook(call: grpc_1.ServerUnaryCall<_PutWebhookRequest, _PutWebhookResponse>, callback: grpc_1.sendUnaryData<_PutWebhookResponse>): void;
        abstract DeleteWebhook(call: grpc_1.ServerUnaryCall<_DeleteWebhookRequest, _DeleteWebhookResponse>, callback: grpc_1.sendUnaryData<_DeleteWebhookResponse>): void;
        abstract ListWebhooks(call: grpc_1.ServerUnaryCall<_ListWebhookRequest, _ListWebhooksResponse>, callback: grpc_1.sendUnaryData<_ListWebhooksResponse>): void;
        abstract GetWebhookSecret(call: grpc_1.ServerUnaryCall<_GetWebhookSecretRequest, _GetWebhookSecretResponse>, callback: grpc_1.sendUnaryData<_GetWebhookSecretResponse>): void;
        abstract RotateWebhookSecret(call: grpc_1.ServerUnaryCall<_RotateWebhookSecretRequest, _RotateWebhookSecretResponse>, callback: grpc_1.sendUnaryData<_RotateWebhookSecretResponse>): void;
    }
    const WebhookClient_base: grpc_1.ServiceClientConstructor;
    export class WebhookClient extends WebhookClient_base {
        constructor(address: string, credentials: grpc_1.ChannelCredentials, options?: Partial<grpc_1.ChannelOptions>);
        PutWebhook: GrpcUnaryServiceInterface<_PutWebhookRequest, _PutWebhookResponse>;
        DeleteWebhook: GrpcUnaryServiceInterface<_DeleteWebhookRequest, _DeleteWebhookResponse>;
        ListWebhooks: GrpcUnaryServiceInterface<_ListWebhookRequest, _ListWebhooksResponse>;
        GetWebhookSecret: GrpcUnaryServiceInterface<_GetWebhookSecretRequest, _GetWebhookSecretResponse>;
        RotateWebhookSecret: GrpcUnaryServiceInterface<_RotateWebhookSecretRequest, _RotateWebhookSecretResponse>;
    }
    export {};
}
